OWL and RDF syntax parsers for OntoLogos.
v0.2 loads OWL/XML, RDF/XML, Turtle, and OWL Functional Syntax into
ontologos_core::Ontology via load_ontology.
Example
use ontologos_parser::load_ontology;
let ontology = load_ontology(std::path::Path::new("ontology.owl"))?;
println!("axioms: {}", ontology.axiom_count());See load guide.
Structs
- Parse
Limits - Resource limits for OWL file parsing.
Enums
Functions
- detect_
format - Detect the most likely format from a file path and optional content sniffing.
- detect_
format_ from_ bytes - Detect format from file content bytes.
- detect_
functional_ from_ bytes - Detect OWL Functional Syntax from a file header.
- detect_
turtle_ from_ bytes - Sniff the first bytes of a file for Turtle
@prefixorPREFIXdeclarations. - load_
ontology - Load an ontology from a validated file path.
- load_
ontology_ in - Load an ontology constrained to stay under
base(untrusted uploads). - load_
ontology_ with_ limits - Load an ontology with custom
ParseLimits. - load_
ontology_ with_ limits_ and_ base - Load an ontology with custom limits and optional sandbox base directory.
- validate_
load_ path - Resolve and validate a path before loading an ontology file.
Type Aliases
- Result
- Result type alias for parser operations.